# gima

`gima` is a `Python` software which simplifies managing many git repositories through the console. It stands for `GI`t `MA`nager.

`gima` is intended to make it easy to `commit`, `pull` and `push` changes for many repositories with easy console interface. The goal of `gima` is not to replace any git client.


## Installation

To install `gima` type in the console:

```
pip install gima
```

To upgrade `gima` type in the console:

```
pip install gima --upgrade
```

## Quick tutorial

[![asciicast](https://asciinema.org/a/1aAV1OK6ixFX3v5JBaN9fpCAL.svg)](https://asciinema.org/a/1aAV1OK6ixFX3v5JBaN9fpCAL)

## Usage

Type in the console:

```
gima
```

and you should see descriptions of all available commands

## Roadmap
There is no specific roadmap for `gima`. New features are added if they are needed.

## Contributing
Feel free to contribute to this project by sending me your opinion, patches, or requesting some features through gitlab issue system.

## Links

Home page: https://gitlab.com/ahypki/gima/                                                                                                                                                                                                                                     
Issues   : https://gitlab.com/ahypki/gima/-/issues/

## License
`gima` is released under the MIT license.
